@@ -8,22 +8,30 @@
 #' @param ... Name-value pairs of expressions. See [dplyr::mutate()].
 #' @param inputs Quosure(s) of `...`.
 #' @template step-return
+#' @template mutate-leakage
 #' @details When an object in the user's global environment is
 #'  referenced in the expression defining the new variable(s),
 #'  it is a good idea to use quasiquotation (e.g. `!!`) to embed
 #'  the value of the object in the expression (to be portable
 #'  between sessions). See the examples.
 #'
-#'  When you [`tidy()`] this step, a tibble with column `values`, which
-#'  contains the `mutate()` expressions as character strings
-#'  (and are not reparsable), is returned.
+#'  If a preceding step removes a column that is selected by name in
+#'  `step_mutate()`, the recipe will error when being estimated with [prep()].
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#'  `values`, which contains the `mutate()` expressions as character
+#'  strings (and are not reparsable), is returned.
+#'
+#' @template case-weights-not-supported
 #'
 #' @family individual transformation steps
 #' @family dplyr steps
 #' @export
 #' @examples
 #' rec <-
-#'   recipe( ~ ., data = iris) %>%
+#'   recipe(~., data = iris) %>%
 #'   step_mutate(
 #'     dbl_width = Sepal.Width * 2,
 #'     half_length = Sepal.Length / 2
@@ -60,7 +68,7 @@
 #' const <- 1.414
 #'
 #' qq_rec <-
-#'   recipe( ~ ., data = iris) %>%
+#'   recipe(~., data = iris) %>%
 #'   step_mutate(
 #'     bad_approach = Sepal.Width * const,
 #'     best_approach = Sepal.Width * !!const
@@ -71,16 +79,12 @@
 #'
 #' # The difference:
 #' tidy(qq_rec, number = 1)
-
-step_mutate <- function(
-  recipe, ...,
-  role = "predictor",
-  trained = FALSE,
-  inputs = NULL,
-  skip = FALSE,
-  id = rand_id("mutate")
-) {
-
+step_mutate <- function(recipe, ...,
+                        role = "predictor",
+                        trained = FALSE,
+                        inputs = NULL,
+                        skip = FALSE,
+                        id = rand_id("mutate")) {
   inputs <- enquos(...)
 
   add_step(
@@ -125,13 +129,9 @@ bake.step_mutate <- function(object, new_data, ...) {
 
 
 print.step_mutate <-
-  function(x, ...) {
-    cat("Variable mutation")
-    if (x$trained) {
-      cat(" [trained]\n")
-    } else {
-      cat("\n")
-    }
+  function(x, width = max(20, options()$width - 35), ...) {
+    title <- "Variable mutation for "
+    print_step(x$inputs, x$inputs, x$trained, title, width)
     invisible(x)
   }
 
